Execution

Struct Execution 

pub struct Execution { /* private fields */ }
An execution.

Implementations

Source

impl Execution

pub fn builder() -> Builder

Create an instance of Execution using the builder syntax

Source

impl Execution

pub fn images(&self) -> &NonEmpty<String>

The images for the execution to run within.

pub fn program(&self) -> &str

The program to execute.

pub fn args(&self) -> &[String]

The arguments to the execution.

pub fn work_dir(&self) -> Option<&str>

The working directory.

pub fn stdin(&self) -> Option<&str>

The file to pipe the standard input stream from.

pub fn stdout(&self) -> Option<&str>

The file to pipe the standard output stream to.

pub fn stderr(&self) -> Option<&str>

The file to pipe the standard error stream to.

pub fn env(&self) -> &IndexMap<String, String>

The environment variables for the execution.